==> hoteldruid-mod-id_3.0.6-1.tar.gz: id/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Reservasi baru"; break;
case "Cliente titolare":  			$messaggio = "Identitas Tamu"; break;
case "cognome":  				$messaggio = "Nama Depan/Keluarga"; break;
case "nome":  					$messaggio = "Nama Belakang"; break;
case "Dal":  					$messaggio = "Tanggal Masuk"; break;
case "dal":  					$messaggio = "dari"; break;
case "al":  					$messaggio = "Sampai"; break;
case "Tipo di tariffa":  			$messaggio = "Jenis harga"; break;
case "sconto":  				$messaggio = "diskon"; break;
case "se diversa dalla normale":  		$messaggio = "jika berbeda dari harga normal"; break;
case "nº di persone":  				$messaggio = "jumlah orang"; break;
case "Nº di piano":  				$messaggio = "Nomor lantai"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "Inserisci la prenotazione":  		$messaggio = "Tambah reservasi"; break;
case "Torna al menù principale":  		$messaggio = "Kembali ke menu utama"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Belum memungkinan untuk membagi reservasi karena jumlah orang"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Belum memungkinan untuk membagi reservasi tanpa"; break;
case "dividerla":  				$messaggio = "membaginya"; break;
case "in":  					$messaggio = "in"; break;
case "Prenotazione":  				$messaggio = "Reservasi"; break;
case "settiman":  				$messaggio = "mingguan"; break;
case "giorn":  					$messaggio = "hari"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "untuk Tuan/Nona/Nyonya"; break;
case "per":  					$messaggio = "untuk"; break;
case "persone":  				$messaggio = "orang"; break;
case "Costo settimanale":  			$messaggio = "Biaya Mingguan"; break;
case "Costo giornaliero":  			$messaggio = "Biaya harian"; break;
case "settimane":  				$messaggio = "minggu"; break;
case "giorni":  				$messaggio = "hari"; break;
case "resto da pagare":  			$messaggio = "sisa pembayaran"; break;
case "inserita":  				$messaggio = "ditambahkan"; break;
case "Modifica la prenotazione":  		$messaggio = "Mengubah reservasi"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "Sconto":  				$messaggio = "Diskon"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Nama depan harus diisi"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Jumlah reservasi dari tipe ini"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Tambah tipe lain"; break;
case "Tipologia":  				$messaggio = "Jenis"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Tidak ada penambahan reservasi baru"; break;
case "Transazione scaduta":  			$messaggio = "Transaksi tidak berlaku"; break;
case "Orario stimato di entrata":  		$messaggio = "Perkiraan waktu check-in"; break;
case "giorno":  				$messaggio = "hari"; break;
case "Metodo pagamento caparra":  		$messaggio = "Metode pembayaran deposit"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Permintaan reservasi dalam pesan sudah ditambah"; break;
case "Attenzione":  				$messaggio = "Peringatan"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "harga total reservasi ditambahkan"; break;
case "Origine":  				$messaggio = "Asli"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Peringatan</b>: total harga"; break;
case "prezzo totale":  				$messaggio = "total harga"; break;
case "prezzo totale giornaliero":  		$messaggio = "total harga harian"; break;
case "prezzo totale settimanale":  		$messaggio = "total harga mingguan"; break;
case "Commissioni":  				$messaggio = "Komisi"; break;
case "resto commissioni":  			$messaggio = "sisa komisi"; break;
case "% del prezzo totale":  			$messaggio = "% dari total biaya"; break;
case "modificata":  				$messaggio = "diubah"; break;
case "costo aggiuntivo":  			$messaggio = "biaya tambahan"; break;
case "per la prenotazione":  			$messaggio = "untuk reservasi"; break;
case "per un promemoria all'entrata":  		$messaggio = "untuk reservasi saat checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "untuk reservasi saat checkout"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "costo aggiuntivo unico":  		$messaggio = "single extra cost"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "nº di settimane da applicare":  		$messaggio = "nº of weeks to apply"; break;
case "nº di giorni da applicare":  		$messaggio = "nº of days to apply"; break;
case " o spezzarla":  				$messaggio = " or dividing it"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide reservation in"; break;
case "parti":  					$messaggio = "pieces"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide the reservation in"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "It was not possible to insert the reservation for"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "because the database has been modified meanwhile"; break;
case "Costo unico":  				$messaggio = "Single cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "confermata":  				$messaggio = "confirmed"; break;
case "Confermata":  				$messaggio = "Confirmed"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "It was not possible to insert an extra cost of the reservation for"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "the total price of inserted deposits"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "is different from the one contained in the reservation request message"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "is different from remote price"; break;
case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Errore":  				$messaggio = "Error"; break;
case "valuta":  				$messaggio = "currency"; break;
case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
case "da":  					$messaggio = "from"; break;
case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
case "Prenotazione non inserita":  			$messaggio = "Reservation not inserted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-id_3.0.7-1.tar.gz: id/prenota.php <==
<?php

switch ($messaggio) {

case "Inserisci una nuova prenotazione":  	$messaggio = "Reservasi baru"; break;
case "Cliente titolare":  			$messaggio = "Identitas Tamu"; break;
case "cognome":  				$messaggio = "Nama Depan/Keluarga"; break;
case "nome":  					$messaggio = "Nama Belakang"; break;
case "Dal":  					$messaggio = "Tanggal Masuk"; break;
case "dal":  					$messaggio = "dari"; break;
case "al":  					$messaggio = "Sampai"; break;
case "Tipo di tariffa":  			$messaggio = "Jenis harga"; break;
case "sconto":  				$messaggio = "diskon"; break;
case "se diversa dalla normale":  		$messaggio = "jika berbeda dari harga normal"; break;
case "nº di persone":  				$messaggio = "jumlah orang"; break;
case "Nº di piano":  				$messaggio = "Nomor lantai"; break;
case "Commento":  				$messaggio = "Keterangan"; break;
case "Inserisci la prenotazione":  		$messaggio = "Tambah reservasi"; break;
case "Torna al menù principale":  		$messaggio = "Kembali ke menu utama"; break;
case "Non é stato possibile dividere la prenotazione a causa del numero di persone":	$messaggio = "Belum memungkinan untuk membagi reservasi karena jumlah orang"; break;
case "Non è possibile inserire la prenotazione senza":	$messaggio = "Belum memungkinan untuk membagi reservasi tanpa"; break;
case "dividerla":  				$messaggio = "membaginya"; break;
case "in":  					$messaggio = "in"; break;
case "Prenotazione":  				$messaggio = "Reservasi"; break;
case "settiman":  				$messaggio = "mingguan"; break;
case "giorn":  					$messaggio = "hari"; break;
case "e":  					$messaggio = "s"; break;
case "a":  					$messaggio = ""; break;
case "o":  					$messaggio = ""; break;
case "i":  					$messaggio = "s"; break;
case "a nome di":  				$messaggio = "untuk Tuan/Nona/Nyonya"; break;
case "per":  					$messaggio = "untuk"; break;
case "persone":  				$messaggio = "orang"; break;
case "Costo settimanale":  			$messaggio = "Biaya Mingguan"; break;
case "Costo giornaliero":  			$messaggio = "Biaya harian"; break;
case "settimane":  				$messaggio = "minggu"; break;
case "giorni":  				$messaggio = "hari"; break;
case "resto da pagare":  			$messaggio = "sisa pembayaran"; break;
case "inserita":  				$messaggio = "ditambahkan"; break;
case "Modifica la prenotazione":  		$messaggio = "Mengubah reservasi"; break;
case "Torna indietro":  			$messaggio = "Kembali"; break;
case "Sconto":  				$messaggio = "Diskon"; break;
case "É necessario inserire il cognome del cliente":	$messaggio = "Nama depan harus diisi"; break;
case "Nº di prenotazioni di questa tipologia":	$messaggio = "Jumlah reservasi dari tipe ini"; break;
case "Aggiungi altre tipologie":  		$messaggio = "Tambah tipe lain"; break;
case "Tipologia":  				$messaggio = "Jenis"; break;
case "Nessuna nuova prenotazione è stata inserita":	$messaggio = "Tidak ada penambahan reservasi baru"; break;
case "Transazione scaduta":  			$messaggio = "Transaksi tidak berlaku"; break;
case "Orario stimato di entrata":  		$messaggio = "Perkiraan waktu check-in"; break;
case "giorno":  				$messaggio = "hari"; break;
case "Metodo pagamento caparra":  		$messaggio = "Metode pembayaran deposit"; break;
case "Le prenotazioni richieste nel messaggio sono già state inserite":	$messaggio = "Permintaan reservasi dalam pesan sudah ditambah"; break;
case "Attenzione":  				$messaggio = "Peringatan"; break;
case "il prezzo totale delle prenotazioni inserite":	$messaggio = "harga total reservasi ditambahkan"; break;
case "Origine":  				$messaggio = "Asli"; break;
case "<b>Attenzione</b>: il prezzo totale":  		$messaggio = "<b>Peringatan</b>: total harga"; break;
case "prezzo totale":  				$messaggio = "total harga"; break;
case "prezzo totale giornaliero":  		$messaggio = "total harga harian"; break;
case "prezzo totale settimanale":  		$messaggio = "total harga mingguan"; break;
case "Commissioni":  				$messaggio = "Komisi"; break;
case "resto commissioni":  			$messaggio = "sisa komisi"; break;
case "% del prezzo totale":  			$messaggio = "% dari total biaya"; break;
case "modificata":  				$messaggio = "diubah"; break;
case "costo aggiuntivo":  			$messaggio = "biaya tambahan"; break;
case "per la prenotazione":  			$messaggio = "untuk reservasi"; break;
case "per un promemoria all'entrata":  		$messaggio = "untuk reservasi saat checkin"; break;
case "per un promemoria all'uscita":  		$messaggio = "untuk reservasi saat checkout"; break;
case "Prenota":  				$messaggio = "Reserve"; break;
case "tariffa":  				$messaggio = "rate"; break;
case "caparra":  				$messaggio = "deposit"; break;
case "e/o di casa":  				$messaggio = "and/or house number"; break;
case "e/o di persone":  			$messaggio = "and/or people number"; break;
case "costo aggiuntivo unico":  		$messaggio = "single extra cost"; break;
case "da moltiplicare per":  			$messaggio = "to multiply by"; break;
case "costo aggiuntivo settimanale":  		$messaggio = "weekly extra cost"; break;
case "costo aggiuntivo giornaliero":  		$messaggio = "daily extra cost"; break;
case "nº di settimane da applicare":  		$messaggio = "nº of weeks to apply"; break;
case "nº di giorni da applicare":  		$messaggio = "nº of days to apply"; break;
case " o spezzarla":  				$messaggio = " or dividing it"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide reservation in"; break;
case "parti":  					$messaggio = "pieces"; break;
case "Spezza la prenotazione in":  		$messaggio = "Divide the reservation in"; break;
case "Non si è potuto inserire la prenotazione a nome di":	$messaggio = "It was not possible to insert the reservation for"; break;
case "perchè il database è stato modificato nel frattempo":	$messaggio = "because the database has been modified meanwhile"; break;
case "Costo unico":  				$messaggio = "Single cost"; break;
case "moltiplicato per":  			$messaggio = "multiplied by"; break;
case "TOTALE":  				$messaggio = "TOTAL"; break;
case "Caparra":  				$messaggio = "Deposit"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "confermata":  				$messaggio = "confirmed"; break;
case "Confermata":  				$messaggio = "Confirmed"; break;
case "Non si è potuto inserire un costo aggiuntivo della prenotazione a nome di":	$messaggio = "It was not possible to insert an extra cost of the reservation for"; break;
case "il prezzo totale delle caparre inserite":	$messaggio = "the total price of inserted deposits"; break;
case "è diverso da quello contenuto nel messaggio di richiesta di prenotazione":	$messaggio = "is different from the one contained in the reservation request message"; break;
case "non coincide con il prezzo remoto":  	$messaggio = "is different from remote price"; break;
case "OVERBOOKING":  				$messaggio = "OVERBOOKING"; break;
case "Modifica come gruppo le prenotazioni inserite":	$messaggio = "Modify inserted reservations as a group"; break;
case "prezzo tariffa":  			$messaggio = "rate price"; break;
case "prezzo tariffa giornaliero":  		$messaggio = "daily rate price"; break;
case "prezzo tariffa settimanale":  		$messaggio = "weekly rate price"; break;
case "% del totale":  				$messaggio = "% of total"; break;
case "% della tariffa":  			$messaggio = "% of rate"; break;
case "Errore":  				$messaggio = "Error"; break;
case "valuta":  				$messaggio = "currency"; break;
case "Il numero di persone inserite non include i bambini (vedere il commento per il numero di bambini)":	$messaggio = "The inserted number of people does not include children (see comment for the number of children)"; break;
case "da":  					$messaggio = "from"; break;
case "Si è dovuto diminuire il <b>numero di persone</b> per inserire la prenotazione":	$messaggio = "The <b>number of people</b> has been decreased in order to insert the reservation"; break;
case "Prenotazione non inserita":  		$messaggio = "Reservation not inserted"; break;
case "Prenotazione non modificata":  		$messaggio = "Reservation not modified"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
